/*
 * Arduino Workbench tekyinblack 2020 - www.tekyinblack.com
 */
/*
 * setupPrecise - setup INA3221 input 
 * drawPreciseFig - read and put INA3221 values on the screen
 * getPreciseCurrent - read current from INA3221 for item
 * getPreciseVoltage - read voltage from INA3221 for item
 * logicPreciseFig - hardware specific code for screen
 */
#include "SDL_Arduino_INA3221.h" 
SDL_Arduino_INA3221 ina3221;
 
void setupPrecise() {
  ina3221.begin();
}

void drawPreciseFig(int itemNo) {
  // routine to draw figure on screen for input from high precision object
  struct touchInfo newTouch;
   float busvoltage = getPreciseVoltage(itemNo) ;
   float current_mA = getPreciseCurrent(itemNo);
  if (workMode == MODE_NORMAL) {
      newTouch = logicPreciseFig(workScreens[itemNo][ITEMX], workScreens[itemNo][ITEMY], 4, busvoltage, current_mA, workScreens[itemNo][PARAM_2], 34);
 
  } else if (workMode == MODE_LARGE){
      newTouch = logicPreciseFig(workScreens[itemNo][ITEMXS], workScreens[itemNo][ITEMYS], 7, busvoltage, current_mA, workScreens[itemNo][PARAM_2], 60);

  } else if (workMode == MODE_FULLSCREEN){
      newTouch = logicPreciseFig(0,50, 14, busvoltage, current_mA, workScreens[itemNo][PARAM_2], 130);

  }
  registerTouch(itemNo, newTouch);
}

float getPreciseCurrent(int itemNo) {
  return ina3221.getCurrent_mA(workScreens[itemNo][PARAM_1]);
}

float getPreciseVoltage(int itemNo) {
  return ina3221.getBusVoltage_V(workScreens[itemNo][PARAM_1]);
}


struct touchInfo logicPreciseFig(int xval, int yval, int textSize, float value1, float value2, int drawColour, int spacer) {
  // draw analog value on screen
  char data[10]; 
  int newWidth = 5*6*textSize;   //  5 characters wide, each of 6 pixels wide times text multiplier
  int newHeight = 8*textSize ;   // 8 pixels wide times text multiplier
  dtostrf(value1, 5, 2, data);
  tft.setTextSize(textSize);
  tft.setTextColor(drawColour, BLACK);
  tft.setCursor(xval, yval);
  tft.print(data);  
  if (reDraw) {
    tft.setTextSize(4);
    tft.print("V");
  }
  tft.setCursor(xval, yval+spacer);
  tft.setTextSize(textSize);
  dtostrf(value2, 5, 2, data);
  tft.print(data);
    if (reDraw) {
    tft.setTextSize(2);
    tft.print("mA");
  }
  return logicTouch(xval, xval + newWidth, yval, yval + newHeight + spacer);
}
